pub enum RetryOperationWhileErrorKind<E, GoneErr = Infallible> {
Gone,
GoneCheckError(GoneErr),
OperationError(Error<E>),
RetriesExhausted(Error<E>),
}Expand description
The kind of error in a RetryOperationWhileError.
Variants
Gone
The gone check indicated that the remote server is permanently unavailable.
GoneCheckError(GoneErr)
The gone check itself failed.
OperationError(Error<E>)
The operation failed with a non-retryable error.
RetriesExhausted(Error<E>)
All retry attempts were exhausted without success.
The contained error is the last retryable error encountered.