pub struct IndefiniteRetryOperationError<E> {
pub attempt: usize,
pub error: Error<E>,
}Expand description
Error produced by retry_operation_indefinitely.
Unlike RetryOperationError, this error has no RetriesExhausted
variant: the indefinite retry function retries transient failures forever,
so the only way it can fail is with a non-retryable operation error.
Fields
attempt: usizeOne-indexed attempt number at which the error occurred.
error: Error<E>The non-retryable operation error.
Implementations
Sourceimpl<E> IndefiniteRetryOperationError<E>
impl<E> IndefiniteRetryOperationError<E>
Sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Returns true if the underlying operation error is a 404 Not Found.